#!/bin/sh -x

PATH=/sbin:/usr/sbin:/bin:/usr/bin

WDOG_ACTION=/etc/init.d/wlan_watchdog.sh
WPA_SUPPLICANT_PID=/var/run/wpa_supplicant.pid

WLANWATCHDOG=1
WWR_COUNTRY_CODE="4000006a"

if [ -e /tmp/ipconfig ] ; then
	. /tmp/ipconfig
fi

COMMAND=${1}
CLONEMAC=${2}
BRACC=1

FAKEMAC=`ubootenv ethaddr`

if [ -e /etc/init.d/ipconfig ] ; then
	. /etc/init.d/ipconfig
fi

USESXJCP=${USESXJCP:-1}
USESXFLDP=${USESXFLDP:-1}
USESXSMP=${USESXSMP:-1}


if [ -r /etc/init.d/bridge.conf ] ; then
	. /etc/init.d/bridge.conf
fi

br_start_direct() {
	/etc/init.d/loadar6k.sh INFRASTRUCTURE ${CLONEMAC} ${FAKEMAC}

	if [ $? -ne 2 ] ; then
		if [ ! -e /sys/class/net/wlan0 ] ; then
			# Driver Load Error -> reboot
			echo "Fail to wlan Driver load!!" > /dev/console
			reboot
		fi
		if [ "${WLANWATCHDOG}" = "1" -a -x /usr/sbin/sxwdogprcd ]; then
			# check [ath6kl] process
			/usr/sbin/sxwdogprcd -D -i 5 -a ${WDOG_ACTION} `ps | grep ath6kl | head -n1 |  sed -e 's/^ *//' -e 's/ .*//'`
		fi
	fi

	ifconfig eth0 0.0.0.0
	brctl addif br0 eth0

	PHY_INDEX=`cat /sys/class/net/wlan0/phy80211/index`
	echo 1 > /sys/kernel/debug/ieee80211/phy${PHY_INDEX}/ath6kl/bridgeable
	brctl addif br0 wlan0

	if [ ${BRACC} -eq 1 ] ; then
		/etc/init.d/startip.sh br0
	fi

	if [ -e /etc/wpa_supplicant.conf ]; then
		cp /etc/wpa_supplicant.conf /tmp/wpa_supplicant.conf
		wpa_supplicant -i wlan0 -B -c /tmp/wpa_supplicant.conf -W -P ${WPA_SUPPLICANT_PID} \
			-b br0 -M ${CLONEMAC}

		WPA_COMMENT=`tail -n 1 /tmp/wpa_supplicant.conf`
		echo "Start wpa_supplicant : ${WPA_COMMENT}"

		# Watch Dog is enable, and wlan I/F is available
		if [ "${WLANWATCHDOG}" = "1" -a -e /sys/class/net/wlan0 -a -x /usr/sbin/sxwdogprcd ]; then
			cnt=0
			PID=""
			while [ $cnt -ne 30 ]; do
				if [ -e ${WPA_SUPPLICANT_PID} ]; then
					PID="`cat ${WPA_SUPPLICANT_PID}`"
					if [ "${PID}" != "" ]; then
						break
					fi
				fi
				usleep 100000
				cnt=`expr ${cnt} + 1`
			done
			/usr/sbin/sxwdogprcd -D -i 5 -a ${WDOG_ACTION} ${PID}
			echo "Start WLAN Watchdog timer($PID) count=${cnt}" > /dev/console
		fi
	fi

	# Start DHCP server
	if [ -x /etc/init.d/udhcpd.sh ]; then
		/etc/init.d/udhcpd.sh br0 sysstart
	fi
}

br_start() {
	ifconfig eth0 -promisc

	# waits for the end of a rcW process.
	while [ ! -e /tmp/init_complete ]
	do
		echo "<BR Wait>"
		usleep 100000
	done

	br_start_direct

	if [ "$REGCC" != "WWR" ] ; then
		#
		# Start JCP server
		#
		if [ ${USESXJCP} -ne "0" ] ; then

			# Startup the protocol depending on an interface
			#
			# Start JCP server
			#
			if [ -x /usr/sbin/jcpd ] ; then
				/etc/init.d/jcpd.sh br0 start
			fi
                fi
		#
		# Start FLDP server
		#
		if [ ${USESXFLDP} -ne "0" ] ; then
			if [ -x /usr/sbin/fldpd ] ; then
				/usr/sbin/fldpd -D -i br0
			fi
		fi
	fi
}

br_stop() {
	echo "Stop bridge"
	ifconfig wlan0 down
}

case "${COMMAND}" in
'start_direct')
	br_start_direct
	;;
'start')
	br_start
	;;
'stop')
	br_stop
	;;
*)
	echo "usage $0 start|stop"
	;;
esac
