#!/bin/sh

# udhcpc script edited by Tim Riker <Tim@Rikers.org>

[ -z "$1" ] && echo "Error: should be called from udhcpc" && exit 1

#echo "default.script params $*"
#env

PIDFILE="/var/run/bb2.pid"
GARPINT=${GARPINT:-60}
RESOLV_CONF="/tmp/resolv.conf"
UDHCPC_CACHE="/var/cache/udhcpc-${interface}.cache"

if [ -e /etc/init.d/ipconfig ]; then
   . /etc/init.d/ipconfig
fi

[ -n "$broadcast" ] && BROADCAST="broadcast $broadcast"
[ -n "$subnet" ] && NETMASK="netmask $subnet"

case "$1" in
	deconfig)
		/sbin/ifconfig $interface 0.0.0.0
		;;

	renew|bound)
		/sbin/ifconfig $interface $ip $BROADCAST $NETMASK

		if [ -n "$router" ] ; then
			echo "deleting routers"
			while route del default gw 0.0.0.0 dev $interface 2>/dev/null; do
				:
			done

			metric=0
			for i in $router ; do
				route add default gw $i dev $interface metric $metric
				metric=`expr $metric + 1`
			done
		fi

		echo -n > $RESOLV_CONF
		[ -n "$domain" ] && echo search $domain >> $RESOLV_CONF
		for i in $dns ; do
			echo adding dns $i
			echo nameserver $i >> $RESOLV_CONF
		done

		echo -n > $UDHCPC_CACHE
		echo ip=$ip >> $UDHCPC_CACHE
		echo mask=$mask >> $UDHCPC_CACHE
		if [ -n "$serverid" ]; then
			# Release DHCP server
			echo serverid=$serverid >> $UDHCPC_CACHE
			echo lease=$lease >> $UDHCPC_CACHE
		elif [ -z "$serverid" -a -n "$siaddr" ]; then
			# Release bootp server
			echo serverid=$siaddr >> $UDHCPC_CACHE
			echo lease=0 >> $UDHCPC_CACHE
		fi

		#
		# Notify SX-570 application of new IP address
		#
		if [ -e "$PIDFILE" ] ; then
			pid=`cat $PIDFILE`
			kill -SIGHUP $pid
		fi

		if [ $GARPINT != 0 ] ; then
			killall -q garpd
			/usr/sbin/garpd -d $GARPINT
		fi
		/etc/init.d/jcpd.sh $interface restart
		;;
esac

exit 0



