#!/bin/sh

ACTION_SCRIPT=/etc/init.d/hostapd_cli_event.sh
CONFIG_FILE=/etc/hostapd.conf
HOSTAPD_PID=/var/run/hostapd.pid
WDOG_ACTION=/etc/init.d/wlan_watchdog.sh


BR_IFNAME=br0
WLAN_IFNAME=wlan0
WLANWATCHDOG=1

if [ -e /tmp/ipconfig ] ; then
	. /tmp/ipconfig
fi

hostapd_start() {
	echo "Starting hostapd..."

	hostapd -B ${CONFIG_FILE} -P ${HOSTAPD_PID}
	brctl addif ${BR_IFNAME} ${WLAN_IFNAME}

	CTRL_FILE=`cat ${CONFIG_FILE} | grep ctrl_interface | cut -d "=" -f 2`
	if [ ! -n "${CTRL_FILE}" ] ; then
		echo "Not specified hostapd ctrl file"
		exit 0
	fi

	cnt=0
	while [ ! -e "${CTRL_FILE}/${WLAN_IFNAME}" ] ; do
		#  Max wait 20 sec
		if [ $cnt -eq 40 ] ; then
			echo "hostapd ctrl file not found!"
			exit 1
		fi
		usleep 500000
		cnt=`expr ${cnt} + 1`
	done

	hostapd_cli -B -i ${WLAN_IFNAME} -a ${ACTION_SCRIPT}

	if [ "${WLANWATCHDOG}" = "1" -a -x /usr/sbin/sxwdogprcd ]; then
		cnt=0
		PID=""
		while [ $cnt -ne 30 ]; do
			if [ -e ${HOSTAPD_PID} ]; then
				PID="`cat ${HOSTAPD_PID}`"
				if [ "${PID}" != "" ]; then
					break
				fi
			fi
			usleep 100000
			cnt=`expr ${cnt} + 1`
		done
		/usr/sbin/sxwdogprcd -D -i 5 -a ${WDOG_ACTION} ${PID}
		echo "Start WLAN Watchdog timer(${PID}) count=${cnt}" > /dev/console
	fi

}

hostapd_stop() {
	echo "Stopping hostapd..."

	if [ "${WLANWATCHDOG}" = "1" ]; then
		PID="`cat ${HOSTAPD_PID}`"	
		kill -TERM `cat /var/run/sxwdogprcd_${PID}.pid`
		rm /var/run/sxwdogprcd_${PID}.pid
		echo "Stop WLAN Watchdog timer(hostapd)" > /dev/console
	fi

	killall hostapd_cli

	brctl delif ${BR_IFNAME} ${WLAN_IFNAME}
	killall hostapd
	rm ${HOSTAPD_PID}
}

case "$1" in
"start")
	hostapd_start
	;;
"stop")
	hostapd_stop
	;;
*)
	echo "usage $0 start|stop"
	exit 1
	;;
esac
