#!/bin/sh

PATH=/sbin:/usr/sbin:/bin:/usr/bin

WIFNAME=$1
MSG=$2

WPS_STATUS_PATH="/tmp/jail/tmp/wps.stat"
SXSPSCONF="/usr/sbin/sxspsconf"

#echo "Recv: [${MSG}]" > /dev/console

wps_event() {

	STAT="`sxsysconf -f ${WPS_STATUS_PATH} LASTSTAT`"

	if [ "${STAT}" != "INPROG" ]; then
		echo "Recv[${1}] But NO INPROG" > /dev/console
		return
	fi

	case "${1}" in
	'WPS_EV_SUCCESS')
		echo " WPS_EV_SUCCESS" > /dev/console
		sxsysconf -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		sxsysconf -f ${WPS_STATUS_PATH} -w SUCCESS RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		;;
	'WPS_EV_FAIL')
		echo " WPS_EV_FAIL" > /dev/console
# complete is not set even if it receives fail Event. 
# It is because hostapd continues processing. 
#		sxsysconf -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		sxsysconf -f ${WPS_STATUS_PATH} -w FAIL RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		;;
	'WPS_EV_PBC_TIMEOUT')
		echo " WPS_EV_PBC_TIMEOUT" > /dev/console
		sxsysconf -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		sxsysconf -f ${WPS_STATUS_PATH} -w TIMEOUT RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		;;
	'WPS_EV_PBC_OVERLAP')
		echo " WPS_EV_PBC_OVERLAP" > /dev/console
		sxsysconf -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		sxsysconf -f ${WPS_STATUS_PATH} -w OVERLAP RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		;;
	'WPS_EV_PIN_TIMEOUT')
		echo " WPS_EV_PIN_TIMEOUT" > /dev/console
		sxsysconf -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		sxsysconf -f ${WPS_STATUS_PATH} -w TIMEOUT RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		;;
	*)
		echo " ${1}"
		;;
	esac
}

wps_settings_updated () {
	echo "Settings Updated" > /dev/console

	#SSID
	SSID="`cat /etc/hostapd.conf | grep "^ssid=" | cut -d "=" -f 2`"

	#WPA Mode 1:WPA 2:WPA2
	TEMP="`cat /etc/hostapd.conf | grep "^wpa=" | cut -d "=" -f 2`"

	# WPA Setting
	if [ -n "${TEMP}" ] ; then
		case "${TEMP}" in
		'1')
			WPA_MODE="WPA-Personal"
			;;
		'2')
			WPA_MODE="WPA2-Personal"
			;;
		'3')
			WPA_MODE="WPA2-Personal"
			;;
		*)
			echo "Invalid WPA Mode" > /dev/console
			return
		esac

		TEMP="`cat /etc/hostapd.conf | grep "^wpa_key_mgmt=" | cut -d "=" -f 2`"
		if [ ${TEMP} != "WPA-PSK" ] ; then
			echo "Invalid wpa_key_mgmt=${TEMP}" > /dev/console
			return
		fi

		TEMP="`cat /etc/hostapd.conf | grep "^wpa_pairwise=" | cut -d "=" -f 2`"
		case "${TEMP}" in
		'TKIP')
			WPA_ENC="TKIP"
			;;
		'CCMP')
			WPA_ENC="AES"
			;;
		'CCMP TKIP')
			WPA_ENC="AUTO"
			;;
		*)
			echo "Invalid WPA Enc" > /dev/console
			return
		esac

		PSK="`cat /etc/hostapd.conf | grep "^wpa_passphrase=" | cut -d "=" -f 2`"
		if [ -z ${PSK} ] ; then
			PSK="`cat /etc/hostapd.conf | grep "^wpa_psk=" | cut -d "=" -f 2`"
			if [ -z ${PSK} ] ; then
				echo "Invalid PSK" > /dev/console
				return
			fi
		fi

		${SXSPSCONF} -w "${SSID}" wifi_ssid
		${SXSPSCONF} -w "${WPA_MODE}" enc_mode
		${SXSPSCONF} -w "${WPA_ENC}" wpa_enc
		${SXSPSCONF} -w "${PSK}" wpa_psk
		### End Configuration set wifi_authtype
		${SXSPSCONF} -w "Open System" wifi_authtype

		### update current security setting
		sxspsconf -c SXFUN update_wifi_security
	else 
		AUTH_ALGS="`cat /etc/hostapd.conf | grep "^auth_algs=" | cut -d "=" -f 2`"
		if [ ${AUTH_ALGS} != "1" ] ; then
			echo "Invalid auth_algs=${AUTH_ALGS}" > /dev/console
			return
		fi
		# Open / WEP OFF
		${SXSPSCONF} -w "${SSID}" wifi_ssid
		${SXSPSCONF} -w "Open" enc_mode
		${SXSPSCONF} -w "WEP_OFF" wep_enable
		### End Configuration set wifi_authtype
		${SXSPSCONF} -w "Open System" wifi_authtype

		### update current security setting
		sxspsconf -c SXFUN update_wifi_security
	fi

}

case "${MSG}" in
'WPS-EVENT')
	wps_event ${3}
	;;
'WPS-NEW-AP-SETTINGS-UPDATED')
	wps_settings_updated
	;;
'RECOVERY')
	/etc/init.d/hostapd.sh stop
	sleep 1
	/etc/init.d/hostapd.sh start
	;;
*)
	;;
esac

