#!/bin/sh

WIFI_MODE=${1}
WIFI_MAC=${2}
FAKE_MAC=${3}

# Define interface
ifc=wlan0

# Fetch configuration file
if [ -e /etc/init.d/ipconfig ] ; then
   . /etc/init.d/ipconfig
fi

#
# Regulatory domain
#   $REGCC
#   $REGDOM
#

# REGDOM is set by BB3 app, only look at country code if not available
if [ -z "$REGDOM" ] ; then

# $REGCC is defined in the ipconfig file
if [ -z "$REGCC" ] ; then
	# This is the first boot
	# Refer to U-Boot environment, which has the default value
	REGCC=`ubootenv regdomain`
	if [ -z "$REGCC" ] ; then
		echo "U-Boot variable 'regdomain' not found!"
		exit 1
	fi
fi

if [ "$REGCC" = "WWR" ] ; then
	REGCC="00"
fi


case "$REGCC" in
"00") REGDOM=0x406A ;;
"US") REGDOM=0x8348 ;;
"DE") REGDOM=0x8114 ;;
"JP") REGDOM=0x8188 ;;
*)    echo "Unknown country code! ${REGCC}"; exit 1 ;;
esac

fi
# end REGDOM not defined conditional

echo "Regulatory domain: ${REGCC} (${REGDOM})"

#
# Load the driver modules
#
DEVPATH=/sys/bus/sdio/devices/mmc0:0001:1
echo -n "mmc0: "

cnt=0
while [ ! -e "$DEVPATH" ] ; do
	if [ $cnt -eq 30 ] ; then
		echo "SDIO CARD not found!"
		exit 2
	fi
	usleep 100000
	cnt=`expr ${cnt} + 1`
done

VENDOR=`cat ${DEVPATH}/vendor`
DEVICE=`cat ${DEVPATH}/device`

load_ath6kl() {
    if [ "$WIFI_MODE" = "ATHTEST" ] ; then
            PARAMS="testmode=1"
    else
            PARAMS="ath6kl_p2p=0"
            PARAMS="${PARAMS} heart_beat_poll=10000 heart_beat_thresh=2"
            if [ "$TXBUNDLE" = "1" ] ; then
                    PARAMS="${PARAMS} low_cpu_power_tx_bundle_max=7 htc_bundle_send_timer=10"
            fi
            if [ -n "${WIFI_MAC}" ] ; then
                    PARAMS="${PARAMS} ath6kl_wifi_mac=${WIFI_MAC}"
            fi
            if [ -n "${FAKE_MAC}" ] ; then
                    PARAMS="${PARAMS} ath6kl_fake_mac=${FAKE_MAC}"
            fi
    fi

	insmod /lib/modules/compat.ko
	insmod /lib/modules/cfg80211.ko

	if [ -n "${WIFI_MAC}" ] ; then
		insmod /lib/modules/ath6kl_sdio.ko reg_domain=${REGDOM}
		cat /sys/class/net/${ifc}/address > /tmp/ifaddr-${ifc}
		rmmod ath6kl_sdio
	fi

	insmod /lib/modules/ath6kl_sdio.ko reg_domain=${REGDOM} ${PARAMS}

	if [ "$TXBUNDLE" = "1" ] ; then
		echo "0 0" > /sys/kernel/debug/ieee80211/phy0/ath6kl/rx_bundle_params
	fi
	echo 0 > /sys/kernel/debug/ieee80211/phy0/ath6kl/tx_amsdu
}

if [ "$VENDOR" != "0x0271" ] ; then
	echo "Unknown SDIO vendor code! ${VENDOR}"
	exit 1
fi

case "$DEVICE" in
0x0301) echo "SX-SDMAN (AR6003)"  ; load_ath6kl ;;
0x0402) echo "SX-SDMAN2 (AR6004)" ; load_ath6kl ;;
*)
	echo "Unknown SDIO device! ${DEVICE}"
	exit 1
	;;
esac


disable_bluetooth() {
	echo 114 > /sys/class/gpio/export
	echo out > /sys/class/gpio/gpio114/direction

	echo 0 > /sys/class/gpio/gpio114/value

	echo 114 > /sys/class/gpio/unexport
}


# Tell kernel the interface is up
ifconfig $ifc up

#
# Although seeding the RNG is unrelated to loading the wireless driver, it
# needs occur after the wireless driver is running and ideally before the
# supplicant or hostapd begins, so I'm doing it here
#
# NOTE: if this script is ever called more than once during normal
# operation, the seeding should only happen once
#
if [ "$WIFI_MODE" != "ATHTEST" ] ; then
   #
   # Seed the kernel's /dev/urandom which may require performing a scan
   # (should only need to scan one time)
   #
   /etc/init.d/doseed $ifc $WIFI_MAC
fi

#  Disable Bluetooth via the BT_PWD_L when the driver is loading is complete 
#disable_bluetooth

exit 0
