#!/bin/sh

PATH=/sbin:/usr/sbin:/bin:/usr/bin
PIDFILE="/var/run/bb2.pid"
PID=0
RESOLV_CONF="/tmp/resolv.conf"

#
# Include IP configuration from bb6k3 application
#
. /etc/init.d/ipconfig

#
# Use interface parameter
#
IFNAME=$1

#
# Make sure IPTRIES is set to something reasonable
#
IPTRIES=${IPTRIES:-3}
GARPINT=${GARPINT:-60}
IPV4DNS1=${IPV4DNS1:-0.0.0.0}
IPV4DNS2=${IPV4DNS2:-0.0.0.0}

#
# Set common DHCP options
#
DHCPOPT="-i $IFNAME -h $HOSTNAME -r $IPV4ADDR -p /var/run/udhcpc.$IFNAME.pid"

#
# First, kill off any active DHCP clients
#
killall -q udhcpc
killall -q garpd

DoStatic() {
#
# Configure the IP address and subnet mask
#
if [ $IPV4MASK != "0.0.0.0" ] ; then
	ifconfig $IFNAME $IPV4ADDR netmask $IPV4MASK
else
	ifconfig $IFNAME $IPV4ADDR netmask 255.255.255.0
fi

if [ $IPV4ROUTER != "0.0.0.0" ] ; then
	#
	# Delete any existing routes and add the new one
	#
	while route del default gw 0.0.0.0 dev $IFNAME ; do
		:
	done
	route add default gw $IPV4ROUTER dev $IFNAME
else
	route add default dev $IFNAME
fi

#
# Set up DNS servers
#
echo -n > $RESOLV_CONF
[ -n "$IPDOMAIN" ] && echo search $IPDOMAIN >> $RESOLV_CONF
[ $IPV4DNS1 != "0.0.0.0" ] && echo nameserver $IPV4DNS1 >> $RESOLV_CONF
[ $IPV4DNS2 != "0.0.0.0" ] && echo nameserver $IPV4DNS2 >> $RESOLV_CONF

#
# If already running, notify SX-570/580 application of IP address
#
if [ -e $PIDFILE ] ; then
   PID=`cat $PIDFILE`
   if [ $PID != 0 ] ; then
      kill -SIGHUP $PID
   fi
fi

if [ $GARPINT != 0 ] ; then
	garpd -d $GARPINT
fi

}

case "$IPV4METHOD" in

static)
	DoStatic
;;

dhcp)

#
# Start a new DHCP client fork to the background if lease cannot
# be immediately obtained
#
udhcpc ${DHCPOPT} -b -s /etc/init.d/dhcp_action.sh

;;

auto)

#
# Try for a little while to get a lease
#
udhcpc ${DHCPOPT} -n -t $IPTRIES -s /etc/init.d/dhcp_action.sh

#
# if no lease was obtained, use configured IP address
#
if [ $? -ne 0 ] ; then
	DoStatic
fi

;;

esac

exit 0
