#!/bin/sh -x

PATH=/sbin:/usr/sbin:/bin:/usr/bin

#
# Include IP configuration
#
if [ -e /etc/init.d/ipconfig ] ; then
	. /etc/init.d/ipconfig
	hostname "$HOSTNAME"
fi

USESFTP=${USESFTP:-0}
USEFTPS=${USEFTPS:-0}

#
# Need self signed certificate generated?
#
if [ ! -e /etc/appcerts/cl.crt ] ; then
   if [ -x /opt/bbsd320 ] ; then
	nice -n 10 /opt/bbsd320 -g
   fi
fi

#
# Verify we have certificates
#
if [ ! -e /etc/appcerts/cl.crt ] ; then
	USEHTTPS=0
	USEFTPS=0
fi
if [ ! -e /etc/appcerts/cl.key ] ; then
	USEHTTPS=0
	USEFTPS=0
fi

#
# Start HTTPd
#
cp /etc/httpd.conf /tmp/lighttpd.conf
if [ $USEHTTPS -ne 0 ] ; then
	cat /etc/appcerts/cl.crt /etc/appcerts/cl.key > /tmp/https.pem
	if [ $USEHTTP -eq 0 ] ; then
		cat /etc/nohttp.conf >> /tmp/lighttpd.conf
	else
		cat /etc/https.conf >> /tmp/lighttpd.conf
	fi
fi
lighttpd -f /tmp/lighttpd.conf

#
# Verify we have a key for SSH and SFTP
#
if [ ! -e /etc/appcerts/db.key ] ; then
   USESSH=0
   USESFTP=0
fi

USER=admin
if [ -e /opt/.username ] ; then
   USER=`cat /opt/.username`
fi

if [ $USESSH -ne 0 -o $USESFTP -ne 0 -o $USETELNET -ne 0 -o $USETFTP -ne 0 ] ; then
	#
	# Make chroot jail
	#
	if [ -x /etc/init.d/makejail.sh ] ; then
		/etc/init.d/makejail.sh ${USER}

		if [ $USESSH -ne 0 ] ; then
			SFTP=/tmp/jail/usr/sbin/sftp-server
			if [ $USESFTP -ne 0 ] ; then
				cp /usr/sbin/sftp-server ${SFTP}
			else
				echo "#!/bin/sh" > ${SFTP}
				echo "exit 0" >> ${SFTP}
				chmod +x ${SFTP}
			fi

			busybox chroot /tmp/jail /usr/sbin/dropbear -jkwr /etc/appcerts/db.key
		fi
		#
		# Configure internet super server as needed
		#
		INETDCONF=/tmp/jail/tmp/inetd.conf
		rm -f ${INETDCONF}

		if [ $USETFTP -ne 0 ] ; then
			echo "tftp dgram udp nowait root /bin/tftpd tftpd -cl /upload" >> ${INETDCONF}
		fi

		if [ $USETELNET -ne 0 ] ; then
			echo "telnet stream tcp nowait root /bin/telnetd telnetd -i" >> ${INETDCONF}
		fi

		#
		# Start internet super server
		#
		if [ -e ${INETDCONF} ] ; then
			busybox chroot /tmp/jail /bin/inetd /tmp/inetd.conf
		fi
	fi
fi

#
# Start FTPS if enabled
#
if [ ${USEFTPS} -ne 0 ] ; then
   VSFTPD_CONF=/tmp/vsftpd.conf
   if [ -e /etc/vsftpd.conf ] ; then
      cp /etc/vsftpd.conf ${VSFTPD_CONF}
      if [ -e /etc/appcerts/ca.crt ] ; then
         echo "ca_certs_file=/etc/appcerts/ca.crt" >> ${VSFTPD_CONF}
      else
         echo "ssl_request_cert=NO" >> ${VSFTPD_CONF}
      fi

      echo ${USER} > /tmp/ftpusers
      echo "userlist_file=/tmp/ftpusers" >> ${VSFTPD_CONF}
      echo "userlist_deny=NO" >> ${VSFTPD_CONF}
      echo "userlist_enable=YES" >> ${VSFTPD_CONF}

      if [ ! -e /usr/share/empty ] ; then
         mkdir -p /usr/share/empty
      fi

      if [ -x /usr/sbin/vsftpd ] ; then
         /usr/sbin/vsftpd ${VSFTPD_CONF}
      fi
   fi
fi
