#!/bin/sh

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin
export PATH

COMMAND=$1
SXSMPD_CONFPATH=$2
ACTIF=$3

IFNAME_CONFPATH=/tmp/ifname
PRODUCTFILE=`sxsysconf -f ${SXSMPD_CONFPATH} SXSMPD_PRODUCTFILEPATH`
ACTIONFILE=`sxsysconf -f ${SXSMPD_CONFPATH} SXSMPD_ACTIONFILEPATH`

check_networkif_enable() {
	local _dev="$1"
	local _enable=0
	if [ -n "${_dev}" ]; then
		ifconfig "${_dev}" | grep UP > /dev/null
		if [ $? -eq 0 ]; then
			_enable=1
		fi
	fi

	## return
	echo "${_enable}"
}

make_smpd_productfile_platform() {
	local _os=`uname`

	if [ "${_os}" = "Linux" ]; then
		_os="linux"
	fi
	printf "[Platform]\n" >> ${PRODUCTFILE}
	echo "OS=${_os}" >> ${PRODUCTFILE}
	echo "" >> ${PRODUCTFILE}
}

make_smpd_productfile_infomation() {
	local _pname=`sxspsconf -c SXFUN show_product_model`
	local _fwversion=`sxspsconf -c SXFUN show_fmw_ver`
	local _series=`sxspsconf -c SXFUN show_product_model`
	local _hostname=`sxspsconf -c SXFUN show_sys_name`
#	local _countrycode=`sxromconf -c GET_COUNTRY`
	local _pcategory=`sxsysconf -f ${SXSMPD_CONFPATH} PRODUCTCATEGORY`
	local _ver_num
	local _ver_last

# Firmware Version
#   for SX System Management Protocol
# 0byte目：Major(1-255)
# 1byte目：Middle(1-255)
# 2byte目：Minor(1-255)
# 3byte目：Option（FC版・255(0xFF))
# 
#   and UTF-8 String (null terminate). max length 64 (+1)

	_fwversion=`echo "${_fwversion}" | sed -e 's/SD3-\|(.*)//g'`

	_ver_num="${_fwversion:0:3}.${_fwversion:3:1}"
	if [ ${#_fwversion} -eq 4 ]; then
		_ver_last="255"
	else
		_ver_last="${_fwversion:4}"
	fi

	printf "[Information]\n" >> ${PRODUCTFILE}
	echo "ProductCategory=${_pcategory}" >> ${PRODUCTFILE}
	echo "ProductName=${_pname}" >> ${PRODUCTFILE}
	echo "FirmwareVersion=${_ver_num}.${_ver_last}" >> ${PRODUCTFILE}
	echo "FirmwareVersionOption=${_fwversion}" >> ${PRODUCTFILE}
	echo "CompanyName=${_series}" >> ${PRODUCTFILE}
	echo "HostName=${_hostname}" >> ${PRODUCTFILE}
#	echo "CountryCode=${_countrycode}" >> ${PRODUCTFILE}
	echo "" >> ${PRODUCTFILE}
}

make_smpd_productfile_protocol() {
local _bridge=`sxsysconf -f ${IFNAME_CONFPATH} ifname`
local _lbcast=`sxsysconf -f ${SXSMPD_CONFPATH} LIMITEDBCAST_SW`
local _vendorid=`sxsysconf -f ${SXSMPD_CONFPATH} VENDORID`

	printf "[Protocol]\n" >> ${PRODUCTFILE}
	echo "Interface=${_bridge}" >> ${PRODUCTFILE}
	echo "LimitedBroadcast=${_lbcast}" >> ${PRODUCTFILE}
	echo "VendorID=${_vendorid}" >> ${PRODUCTFILE}
	echo "" >> ${PRODUCTFILE}
}

make_smpd_productfile_interfacecnt() {
	local _wired_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIREDIF_COUNT`
	local _wirelessH_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIRELESS_HALIF_COUNT`
	local _wirelessV_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIRELESS_VAPIF_COUNT`
	local _bridge_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} BRIDGEIF_COUNT`
	local _vlan_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} VLANIF_COUNT`
	local _usb_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} USBIF_COUNT`
	local _serial_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} SERIALIF_COUNT`
	local _vsp_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} VSPIF_COUNT`

	printf "[Interface Count]\n" >> ${PRODUCTFILE}
	echo "Wired=${_wired_cnt}" >> ${PRODUCTFILE}
	echo "WirelessHAL=${_wirelessH_cnt}" >> ${PRODUCTFILE}
	echo "WirelessVAP=${_wirelessV_cnt}" >> ${PRODUCTFILE}
	echo "Bridge=${_bridge_cnt}" >> ${PRODUCTFILE}
	echo "VLAN=${_vlan_cnt}" >> ${PRODUCTFILE}
	echo "USB=${_usb_cnt}" >> ${PRODUCTFILE}
	echo "Serial=${_serial_cnt}" >> ${PRODUCTFILE}
	echo "VirtualSerial=${_vsp_cnt}" >> ${PRODUCTFILE}
	echo "" >> ${PRODUCTFILE}

}

make_smpd_productfile_wired() {
	local _wired_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIREDIF_COUNT`
	local i=0
	local _index=${1}
	local _wiredenable=""
	local _wiredif=""

	while [ ${i} -lt ${_wired_cnt} ]; do
		CFG_IDX="`expr ${i} + 1`"
		_wiredif=`sxsysconf -f ${SXSMPD_CONFPATH} WIRED_INTERFACE`
		_wiredenable=`sxsysconf -f /tmp/ifname ifname | grep -c -e "eth0\|br0"`

		echo "[Wired_${CFG_IDX}]" >> ${PRODUCTFILE}
		echo "Index=${_index}" >> ${PRODUCTFILE}
		echo "Enable=${_wiredenable}" >> ${PRODUCTFILE}
		echo "Device=${_wiredif}" >> ${PRODUCTFILE}
		i=`expr $i + 1`
		_index=`expr $_index + 1`
	done
	echo "" >> ${PRODUCTFILE}

	## return
	echo "${_index}"

}
make_smpd_productfile_wlhal() {
	## Wireless HAL
	local i=0
	local _index=${1}
	local _wlhal_enable=""
	local _wlhal_mac=""
	local _wlhal_devname=`sxsysconf -f ${SXSMPD_CONFPATH} WLAN_HAL_DEV_BASENAME`
	local _wlhal_driver=`sxsysconf -f ${SXSMPD_CONFPATH} WLAN_HAL_DRIVER`
	local _wirelessH_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIRELESS_HALIF_COUNT`

	while [ ${i} -lt ${_wirelessH_cnt} ]; do
		CFG_IDX="`expr ${i} + 1`"
		_wlhal_mac=`sxsysconf -f ${IFNAME_CONFPATH} WLAN_MODULE_ADDR`
		_wlhal_dev="${_wlhal_devname}${i}"
		_wlhal_enable=0
		_wlhal_enable=`sxsysconf -f /tmp/ifname ifname | grep -c -e "wlan0\|br0"`

		echo "[WirelessHAL_${CFG_IDX}]" >> ${PRODUCTFILE}
		echo "Index=${_index}" >> ${PRODUCTFILE}
		echo "Enable=${_wlhal_enable}" >> ${PRODUCTFILE}
		echo "Device=${_wlhal_dev}" >> ${PRODUCTFILE}
		echo "Driver=${_wlhal_driver}" >> ${PRODUCTFILE}
		echo "MAC=${_wlhal_mac}" >> ${PRODUCTFILE}
		i=`expr $i + 1`
		_index=`expr $_index + 1`
		echo "" >> ${PRODUCTFILE}
	done

	## return
	echo ${_index}
}
make_smpd_productfile_wlvap() {
	## Wireless VAP
	local i=0
	local _index=${1}
	local _wlvap_enable=""
	local _wlvap_dev=""
	local _wlvap_devname=`sxsysconf -f ${SXSMPD_CONFPATH} WLAN_VAP_DEV_BASENAME`
	local _wlvap_driver=`sxsysconf -f ${SXSMPD_CONFPATH} WLAN_VAP_DRIVER`
	local _wlvap_hal=`sxsysconf -f ${SXSMPD_CONFPATH} WLAN_VAP_HALNAME`
	local _wirelessV_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} WIRELESS_VAPIF_COUNT`

	while [ ${i} -lt ${_wirelessV_cnt} ]; do
		CFG_IDX="`expr ${i} + 1`"
		_wlvap_dev="${_wlvap_devname}${i}"
		_wlvap_enable=0
		_wlvap_enable=`sxsysconf -f /tmp/ifname ifname | grep -c -e "wlan0\|br0"`

		echo "[WirelessVAP_${CFG_IDX}]" >> ${PRODUCTFILE}
		echo "Index=${_index}" >> ${PRODUCTFILE}
		echo "Enable=${_wlvap_enable}" >> ${PRODUCTFILE}
		echo "Device=${_wlvap_dev}" >> ${PRODUCTFILE}
		echo "Driver=${_wlvap_driver}" >> ${PRODUCTFILE}
		echo "HAL=${_wlvap_hal}" >> ${PRODUCTFILE}
		i=`expr $i + 1`
		_index=`expr $_index + 1`
		echo "" >> ${PRODUCTFILE}
	done

	## return
	echo ${_index}
}

make_smpd_productfile_serial() {
	## Wireless HAL
	local i=0
	local _index=${1}
	local _serial_enable=""
	local _serial_devname=`sxsysconf -f ${SXSMPD_CONFPATH} SERIAL_DEV_BASENAME`
	local _serial_driver=`sxsysconf -f ${SXSMPD_CONFPATH} SERIAL_DRIVER`
	local _serial_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} SERIALIF_COUNT`

	while [ ${i} -lt ${_serial_cnt} ]; do
		CFG_IDX="`expr ${i} + 1`"
		_serial_enable=1
		_serial_dev="${_serial_devname}${i}"

		echo "[Serial_${CFG_IDX}]" >> ${PRODUCTFILE}
		echo "Index=${_index}" >> ${PRODUCTFILE}
		echo "Enable=${_serial_enable}" >> ${PRODUCTFILE}
		echo "Device=${_serial_dev}" >> ${PRODUCTFILE}
		echo "Driver=${_serial_driver}" >> ${PRODUCTFILE}
		i=`expr $i + 1`
		_index=`expr $_index + 1`
		echo "" >> ${PRODUCTFILE}
	done

	## return
	echo ${_index}
}
make_smpd_productfile_vsp() {
	## Wireless HAL
	local i=0
	local _index=${1}
	local _vsp_enable=""
	local _vsp_driver=`sxsysconf -f ${SXSMPD_CONFPATH} VSP_DRIVER`
	local _vsp_hal=`sxsysconf -f ${SXSMPD_CONFPATH} VSP_HALNAME`
	local _vsp_cnt=`sxsysconf -f ${SXSMPD_CONFPATH} VSPIF_COUNT`

	while [ ${i} -lt ${_vsp_cnt} ]; do
		CFG_IDX="`expr ${i} + 1`"
		_vsp_enable=1

		echo "[VirtualSerial_${CFG_IDX}]" >> ${PRODUCTFILE}
		echo "Index=${_index}" >> ${PRODUCTFILE}
		echo "Enable=${_vsp_enable}" >> ${PRODUCTFILE}
		echo "Driver=${_vsp_driver}" >> ${PRODUCTFILE}
		echo "HAL=${_vsp_hal}" >> ${PRODUCTFILE}
		i=`expr $i + 1`
		_index=`expr $_index + 1`
		echo "" >> ${PRODUCTFILE}
	done

	## return
	echo ${_index}
}

make_smpd_productfile_ifindex() {
	local _ifindex=`sxsysconf -f ${SXSMPD_CONFPATH} IFINDEX_START`
	local _ifindex_sprit=`sxsysconf -f ${SXSMPD_CONFPATH} IFINDEX_SPRIT`
	local _ifindex_max=`sxsysconf -f ${SXSMPD_CONFPATH} IFINDEX_MAX`
	local _endindex="${1}"

	## I/F index setting!
	while [ ${_ifindex} -lt ${_ifindex_max} ]; do
		_ifindex=`expr ${_ifindex} + ${_ifindex_sprit}`
		if [ ${_endindex} -lt ${_ifindex} ]; then
			break;
		fi
	done

	## return
	echo "${_ifindex}"

}
make_smpd_productfile() {
	local _ifindex=`sxsysconf -f ${SXSMPD_CONFPATH} IFINDEX_START`

	mkdir -p ${PRODUCTFILE%/*}

	echo "" > ${PRODUCTFILE}
	make_smpd_productfile_platform
	make_smpd_productfile_infomation
	make_smpd_productfile_protocol
	make_smpd_productfile_interfacecnt

	## wired
	_index=`make_smpd_productfile_wired ${_ifindex}`
	_ifindex=`make_smpd_productfile_ifindex ${_index}`

	## Wireless HAL
	_index=`make_smpd_productfile_wlhal ${_ifindex}`
	_ifindex=`make_smpd_productfile_ifindex ${_index}`

	## Wireless VAP
	_index=`make_smpd_productfile_wlvap ${_ifindex}`
	_ifindex=`make_smpd_productfile_ifindex ${_index}`

	## Serial
	_index=`make_smpd_productfile_serial ${_ifindex}`
	_ifindex=`make_smpd_productfile_ifindex ${_index}`

	## VSP
	_index=`make_smpd_productfile_vsp ${_ifindex}`
	_ifindex=`make_smpd_productfile_ifindex ${_index}`
}

start_smpd() {
	echo "start SX-SMP Daemon."
	sx_smpd -c ${PRODUCTFILE} -a ${ACTIONFILE} -D
}

stop_smpd() {
	echo "stop SX-SMP Daemon."
	killall sx_smpd
}

case "$COMMAND" in
'make_productfile')
	make_smpd_productfile
	;;
'start')
	start_smpd
	;;
'stop')
	stop_smpd
	;;
'restart')
	stop_smpd
	sleep 3
	start_smpd
	;;
*)
	echo "usage $0 start|stop|restart|make_productfile"
esac


