#!/bin/sh

WIFNAME=$1
CMD=$2
ifname=wlan0

WPS_STATUS_PATH="/tmp/jail/tmp/wps.stat"
SXSPSCONF="/usr/sbin/sxspsconf"
SXSYSCONF="/usr/sbin/sxsysconf"
WPACLI="/usr/bin/wpa_cli"
BRIFNAME="br0"

if [ -r /tmp/ifname ]; then
    . /tmp/ifname
fi


echo "Recv: [${CMD}]" > /dev/console


#
# Resume network setting before wps executing
#
wps_resume_network() {
	CUR_NETID="`${WPACLI} -i ${WIFNAME} list_network | grep CURRENT | cut -f1`"
	BEFORE_NETID="`${SXSYSCONF} -f ${WPS_STATUS_PATH} BEFORE_NETID`"

	echo "Resume WLAN Network ID[${BEFORE_NETID}] -> [${CUR_NETID}]" > /dev/console

	if [ -n "${BEFORE_NETID}" -a "${CUR_NETID}" != "${BEFORE_NETID}" ] ; then
		${WPACLI} -i  ${WIFNAME} select_network ${BEFORE_NETID}
		echo "Resume WLAN Network Setting [${BEFORE_NETID}]" > /dev/console
	fi
}

wps_settings_updated () {
	NETID=${1}

	echo "Settings Updated id=${NETID}" > /dev/console

	#SSID
	SSID=`${WPACLI} -i ${WIFNAME} get_network ${NETID} ssid`
	#delete double quote["]
	NUM=`expr ${#SSID} - 1`
	SSID=`echo ${SSID} | cut -c 2-${NUM}`

	#KEY MGMT
	KEY_MGMT="`${WPACLI} -i ${WIFNAME} get_network ${NETID} key_mgmt`"

	case "${KEY_MGMT}" in
	'NONE')
		AUTH="`${WPACLI} -i ${WIFNAME} get_network ${NETID} auth_alg`"
		if [ ${AUTH} != "OPEN" ]; then
			echo "Invalid auth_algs ${AUTH}" > /dev/console
			return 2
		fi

		# Open / WEP OFF
		${SXSPSCONF} -w "INFRASTRUCTURE" wifi_mode
		${SXSPSCONF} -w "${SSID}" wifi_ssid
		${SXSPSCONF} -w "Open" enc_mode
		${SXSPSCONF} -w "WEP_OFF" wep_enable
		### End Configuration set wifi_authtype
		${SXSPSCONF} -w "Open System" wifi_authtype

		### WPS Setting
		${SXSPSCONF} -w "Open" wps_authtype
		${SXSPSCONF} -w "NONE" wps_encrtype
		${SXSPSCONF} -w "1" wps_setting

		### update current security setting
		sxspsconf -c SXFUN update_wifi_security
		;;
	'WPA-PSK')
		WPS_ENC="`${WPACLI} -i ${WIFNAME} get_network ${NETID} pairwise`"
		case "${WPS_ENC}" in
		'TKIP')
			WPA_ENC="TKIP"
			;;
		'CCMP')
			WPA_ENC="AES"
			;;
		'CCMP TKIP')
			WPA_ENC="AUTO"
			;;
		*)
			echo "Invalid WPA ENC ${TEMP} to Auto" > /dev/console
			WPA_ENC="AUTO"
			;;
		esac

		WPS_WPA_ENC=${WPA_ENC}

		#WPA Mode 1:WPA[WPA] 2:WPA2[RSN]
		PROTO="`${WPACLI} -i ${WIFNAME} get_network ${NETID} proto`"
		case "${PROTO}" in
		'WPA')
			WPA_MODE="WPA-Personal"
			WPS_WPA_MODE="WPA-Personal"
			if [ ${WPA_ENC} != "AUTO" ]; then
				echo "update WPA ENC to Auto" > /dev/console
				WPA_ENC="AUTO"
			fi
			;;
		'RSN')
			WPA_MODE="WPA2-Personal"
			WPS_WPA_MODE="WPA2-Personal"
			if [ ${WPA_ENC} != "AES" ]; then
				echo "change WPA2 ENC ${WPA_ENC} to AES" > /dev/console
				WPA_ENC="AES"
			fi
			;;
		'WPA RSN')
			# WPA/WPA2-Mixed Mode is WPA
			WPA_MODE="WPA-Personal"
			WPS_WPA_MODE="WPA/WPA2-Personal"
			echo "Change WPA-Mixed Mode to WPA-Personal" > /dev/console
			if [ ${WPA_ENC} != "AUTO" ]; then
				echo "update WPA ENC to Auto" > /dev/console
				WPA_ENC="AUTO"
			fi
			;;
		*)
			echo "Invalid WPA Mode ${PROTO} to WPA2-Personal" > /dev/console
			WPA_MODE="WPA2-Personal"
			WPS_WPA_MODE="WPA/WPA2-Personal"
			if [ ${WPA_ENC} != "AES" ]; then
				echo "change WPA2 ENC ${WPA_ENC} to AES" > /dev/console
				WPA_ENC="AES"
			fi
			;;
		esac

		PSK="`${WPACLI} -i ${WIFNAME} get_network ${NETID} psk`"

		#delete double quote["]
		NUM=${#PSK}
		STARTC=`echo ${PSK} | cut -c 1`
		ENDC=`echo ${PSK} | cut -c ${NUM}`
		if [ "${STARTC}" = "\"" -a "${ENDC}" = "\"" ]; then
			NUM=`expr ${#PSK} - 1`
			PSK=`echo ${PSK} | cut -c 2-${NUM}`
		fi

		if [ ${#PSK} -lt 8 -o ${#PSK} -gt 64 ] ; then
			echo "Invalid PSK Length ${PSK}" > /dev/console
			return 2
		fi

		${SXSPSCONF} -w "INFRASTRUCTURE" wifi_mode
		${SXSPSCONF} -w "${SSID}" wifi_ssid
		${SXSPSCONF} -w "${WPA_MODE}" enc_mode
		${SXSPSCONF} -w "${WPA_ENC}" wpa_enc
		${SXSPSCONF} -w "${PSK}" wpa_psk
		### End Configuration set wifi_authtype
		${SXSPSCONF} -w "Open System" wifi_authtype

		### WPS Setting
		${SXSPSCONF} -w "${WPS_WPA_MODE}" wps_authtype
		${SXSPSCONF} -w "${WPS_WPA_ENC}"  wps_encrtype
		${SXSPSCONF} -w "1" wps_setting

		### update current security setting
		sxspsconf -c SXFUN update_wifi_security
		;;
	*)
		echo "Invalid KEY MGMT ${KEY_MGMT}" > /dev/console
		return 2
	esac

	echo "Updated config" > /dev/console

	return 3
}

wpa_connected () {
	# check update configration
	WAIT_CONNECT=`${SXSYSCONF} -f ${WPS_STATUS_PATH} WAIT_CONNECT`
	if [ "${WAIT_CONNECT}" = "1" ] ; then
		wps_settings_updated ${WPA_ID}
		RET=${?};
		${SXSYSCONF} -f ${WPS_STATUS_PATH} -w "${RET}" WAIT_CONNECT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
	fi

	if [ "${ifname}" = "${WIFNAME}" ]; then
		# SSID=`wpa_cli -i$WIFNAME status | grep ^ssid= | cut -f2- -d=`
		# configure network, signal DHCP client, etc.
		# echo "WLAN Connected to SSID $SSID" >/tmp/wlan0
		/etc/init.d/startip.sh $WIFNAME
		/etc/init.d/jcpd.sh $WIFNAME restart

		# Start DHCP server
		if [ -x /etc/init.d/udhcpd.sh ]; then
		/etc/init.d/udhcpd.sh $WIFNAME sysstart
		fi
	fi
}

wpa_disconnected () {
    remove network configuration, if needed
    echo "WLAN disconnected" >/tmp/wlan0
}

case "${CMD}" in
'CONNECTED')
	wpa_connected
	;;
'WPS-SUCCESS')
	echo " ${CMD}" > /dev/console
	${SXSYSCONF} -f ${WPS_STATUS_PATH} -w "1" WAIT_CONNECT
	${SXSYSCONF} -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
	${SXSYSCONF} -f ${WPS_STATUS_PATH} -w SUCCESS RESULT
        # Restore user mode read permission stomped by sxsysconf
        chmod 666 ${WPS_STATUS_PATH}
	;;
'WPS-FAIL')
	LSTAT="`${SXSYSCONF} -f ${WPS_STATUS_PATH} LASTSTAT`"
	echo " ${CMD} _LSTAT=${LSTAT}" > /dev/console
	if [ ${LSTAT} == "INPROG" ]; then
		${SXSYSCONF} -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		${SXSYSCONF} -f ${WPS_STATUS_PATH} -w FAIL RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		wps_resume_network
	fi
	;;
'WPS-TIMEOUT')
	echo " ${CMD}" > /dev/console
	LSTAT="`${SXSYSCONF} -f ${WPS_STATUS_PATH} LASTSTAT`"
	echo " ${CMD} _LSTAT=${LSTAT}" > /dev/console
	if [ ${LSTAT} == "INPROG" ]; then
		${SXSYSCONF} -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
		${SXSYSCONF} -f ${WPS_STATUS_PATH} -w TIMEOUT RESULT
                # Restore user mode read permission stomped by sxsysconf
                chmod 666 ${WPS_STATUS_PATH}
		wps_resume_network
	fi
	;;
'WPS-OVERLAP-DETECTED')
	echo " ${CMD}" > /dev/console
	${SXSYSCONF} -f ${WPS_STATUS_PATH} -w COMPLETE LASTSTAT
	${SXSYSCONF} -f ${WPS_STATUS_PATH} -w OVERLAP RESULT
        # Restore user mode read permission stomped by sxsysconf
        chmod 666 ${WPS_STATUS_PATH}
	wps_resume_network
	;;
*)
	;;
esac

