#!/bin/sh
#
# This script is executed by inotifyd when a file is closed in
# /tmp/jail/upload, or by the sxsmp protocol processor when
# a file has been downloaded.
#
event=$1
directory=$2
tarball=$3

#
# Delete sxsmpd.fwup file if it exests
#
SMPD_FWUP_DIR="/tmp/smp_upload"
SMPD_FWUP_FILE="${SMPD_FWUP_DIR}/sxsmpd.fwup"
SMPD_FWUP=0
VER_FILE="/opt/.version"

if [ -e ${SMPD_FWUP_FILE} ]; then
	rm -f ${SMPD_FWUP_FILE}
	SMPD_FWUP=1
fi

cd ${directory}
echo "Firmware update from " ${directory} > /dev/console

#
# If filename contains .cmd, process as console commands
#
if [ "$tarball" != "${tarball/*.cmd/}" ]; then
	console -f $tarball
	exit 0
fi

#
# If filename does not contain .bin, ignore it
#
if [ "$tarball" == "${tarball/*.bin/}" ]; then
   exit 0
fi

#
# See if signature OK
#
sigtool -v1 $tarball
if [ $? -ne 0 ] ; then
   echo "$tarball signature fail" > /dev/console
   exit 5
fi

#
# Extract update script which must be there in every valid script
#
rm -f update.sh
tar -jxf $tarball update.sh
if [ $? != 0 ] ; then
   echo -e "\nInvalid firmware binary" > /dev/console
   rm -f $tarball
   exit 4
fi

#
# Check for correct firmware for this product
#
grep "Model: SX-300/SD320AN" update.sh > /dev/null
if [ $? != 0 ] ; then
    echo -e "\nInvalid firmware for this device" > /dev/console
    exit 3
fi

if [ ${SMPD_FWUP} -eq 1 ]; then
	echo -e "\nSMPD firmware update checks complete, unit needs to be rebooted to install" > /dev/console
        #
        # Actual update is deferred to rcD shutdown
        # script when unit is rebooted, to give status
        # reply time to get to the host.
        #
        exit 0
fi

#
# Remove /opt/.version before updating in case new firmware does not
# need this file
#
if [ -e ${VER_FILE} ]; then
	rm -f ${VER_FILE}
fi

./update.sh $tarball > /dev/console
#    rm -f $tarball
#
# Remove SMP update directory so there is not
# an inadvertant second update when the
# unit reboots.  Should be nothing there, but
# it doesn't hurt to be sure
#
if [ -e ${SMPD_FWUP_DIR} ]; then
	rm -rf ${SMPD_FWUP_DIR}
fi

exit 0
