#!/bin/sh -x

#
# Firmware update script
# Model: SX-300/SD320AN
# Model: SX-582-2700
# Created: 2018.01.02
# BoardRev: 2
#
# $1 is the name of the tarball
#
TB=$1

# Remember where we started
WD=`pwd`

echo $WD

if [ -z "$TB" ] ; then
   echo -e "\nUsage: update.sh tarball"
   exit 1
fi

echo -e "\nFirmware update in progress. Do NOT power off!"

if [ ! -x blinkled ] ; then
   tar -jxf $TB blinkled
fi
if [ ! -x blinkled ] ; then
   echo -e "\nblinkled NOT FOUND\n"
   exit 1
fi

# Begin blinking the LED during the update
./blinkled

# Kill off all applications that we will be updating
# (listed in alphabetical order)
killall -q \
        bbsd320 \
        sx_smpd \
        sxwdogprcd \
        console \
        fldpd \
        garpd \
        hostapd \
        hostapd_cli \
        inetd \
        inotifyd \
        jcpd \
        jcpd_uvl \
        ntpd \
        snmpd \
        sxbrd \
        thttpd \
        udhcpc \
        udhcpd \
        wpa_cli \
        wpa_supplicant \
        syslogd \
        klogd 

# Fetch all the files at once - faster than one at a time
tar -jxf $TB

#
# If /home/admin exists, we need to update /etc/passwd
# which we usually do not do (see below)
#
if [ -d /home/admin ] ; then
        cp tree/etc/passwd /etc/passwd
	rmdir /home/admin
fi

#
# Prevent configuration files from being overwritten
#
CONFIG_FILES="
        /etc/init.d/dhcpscfg
        /etc/init.d/ipconfig
        /etc/wpa_supplicant.conf
        /etc/shadow
        /etc/passwd
        /etc/group
        /etc/wpa_supplicant_null.conf
"
for i in $CONFIG_FILES; do
        if [ -e "$i" ]; then
                rm -f "tree$i"
        fi
done

# Prepare to replace www files with newer ones
#rm -rf /usr/www/*

# Remove the old HTTP server being replaced
rm -rf /usr/sbin/thttpd
rm -rf /etc/thttpd.conf

# Remove AP mode support
rm -rf /usr/sbin/hostapd
rm -rf tree/usr/sbin/hostapd

# Remove the C++ library if present
rm -rf /usr/lib/libstdc++.so.6.0.13

# Remove reset and syslog web pages
rm -rf /usr/www/restart.htm
rm -rf /usr/www/syslog.htm
rm -rf /usr/www/rename.htm

# Update wifi cert directory permissions for web server
# create it if for some reason it doesn't exist.
if [ ! -d /etc/certs ] ; then
	mkdir /etc/certs
fi
chmod 777 /etc/certs

# Add SSL configuration directory
if [ ! -d /etc/appcerts ] ; then
	mkdir /etc/appcerts
        chmod 777 /etc/appcerts
fi

# Update web sxssi directory permissions for web server
# create it if for some reason it doesn't exist.
if [ ! -d /etc/sxssi ] ; then
	mkdir /etc/sxssi
fi
chmod 777 /etc/sxssi



if [ ! -d /var/lib/misc ] ; then
	ln -sf ../../tmp /var/lib/misc 
fi

#
# update busybox first
#
busybox_updatefile() {
	cd $1
	md5sum -c -s $WD/$2.md5
	if [ $? -ne 0 ] ; then
		cd $WD
		$WD/$2 cp -f $2 $1/$2
        	if [ $? -ne 0 ] ; then
	   	    echo -e $1/$2 " update FAILED"
                else
	   	    echo -e $1/$2 " updated"
                fi
                
		# update busybox symbolic links
                $1/$2 --install -s
                echo "New busybox installed"
	fi
	cd $WD
	rm -f $2 $2.md5
}

#
busybox_updatefile "/bin" "busybox"



# Update files
cd tree
find . -type f -exec ../install.sh {} ../tree.md5/{}.md5 \;

#
# Add new symbolic links
#
updatelink() {
   if [ -e $1/$2 ] ; then
      cmp -s $1/$2 $1/$3
      if [ $? == 0 ] ; then
	# Link is correct - our job is done
	return 0
      fi
   fi
   # Delete incorrect link
   rm -f $1/$2
   cd $1
   # Create new link
   ln -s $3 $2
   cd $WD
}

updatelink "/lib" "libpcre.so" "libpcre.so.1.2.8" 
updatelink "/lib" "libpcre.so.1" "libpcre.so.1.2.8" 



#
# Confirm we have a valid kernel before erasing the old one
#
cd $WD
md5sum -c -s uImage.md5
if [ $? -eq 0 ] ; then
        echo -e "\nInstalling new kernel..."
        busybox flashcp -v uImage /dev/mtd2
        if [ $? -ne 0 ] ; then
                echo -e "\n!! Kernel installation failure !!"
                exit 0
        fi
         echo -e "\nNew kernel installed"
else
        echo -e "\nNew kernel image not valid. Update aborted"
        reboot
fi

#
# Flush flash changes and dismount file system
#
sync
sync
mount -r -o remount /

SMPD_FWUP_FILE="/tmp/smp_upload/update.sh"
if [ ! -e ${SMPD_FWUP_FILE} ]; then
	echo -e "\nFirmware update completed successfully. Restarting..."
	reboot
else
	echo -e "\nSMPD firmware update installed, reboot continuing"
fi
